@@ -1,7 +1,6 @@
 from ph_data_clean.clean.data_clean import DataClean
 from ph_data_clean.clean.cpa_gyc_data_clean import CpaGycDataClean
 from ph_data_clean.clean.chc_data_clean import ChcDataClean
-from ph_data_clean.clean.product_data_clean import ProductDataClean
 from ph_data_clean.clean.universe_data_clean import UniverseDataClean
 from pherrs.ph_err import PhError
 
@@ -15,7 +14,6 @@ class CleanerFactory(object):
         ('CPA', 'GYC', 'CPA&GYC', 'GYC&CPA', 'CPA&PTI&DDD&HH'): CpaGycDataClean,
         ('CHC',): ChcDataClean,
         ('universe',): UniverseDataClean,
-        ('product',): ProductDataClean,
     }
 
     def get_specific_cleaner(self, source, company='') -> DataClean:
